| Title: | Differential Item Functioning via Shiny Application |
|---|---|
| Description: | Differential Item Functioning (DIF) Analysis with shiny application interfaces. You can run the functions in this package without any arguments and perform your DIF analysis using user-friendly interfaces. |
| Authors: | Huseyin Yildiz [aut, cre] |
| Maintainer: | Huseyin Yildiz <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-05-27 07:12:03 UTC |
| Source: | https://github.com/cran/DIFshiny |
By using the functions in this package without any arguments, you can perform your Differential Item Functioning (DIF) analysis with user-friendly shiny interfaces.
DIFshiny()DIFshiny()
No return value, launches application
if(interactive()){ DIFshiny() }if(interactive()){ DIFshiny() }